@@ -18,7 +18,21 @@ import os
 from urllib.parse import urlparse
 
 # %% Main
-def scatterd(x, y, z=None, s=50, c=[0, 0, 0], labels=None, marker=None, alpha=None, gradient=None, density=False, norm=False, cmap='Set1', figsize=(25, 15), legend=True, ax=None,
+def scatterd(x,
+             y,
+             z=None,
+             s=50,
+             c=[0, 0, 0],
+             labels=None,
+             marker=None,
+             alpha=None,
+             gradient=None,
+             density=False,
+             norm=False,
+             cmap='Set1',
+             figsize=(25, 15),
+             legend=True,
+             ax=None,
              xlabel='x-axis', ylabel='y-axis', title='', fontsize=24, fontcolor=None, axiscolor='#dddddd',
              args_density = {'cmap': 'Reds', 'shade': True, 'thresh': 0.05, 'bw_adjust': .6, 'alpha': 0.66, 'legend': False, 'cbar': False, 'fill': True}):
     """Make scaterplot.
@@ -54,7 +68,7 @@ def scatterd(x, y, z=None, s=50, c=[0, 0, 0], labels=None, marker=None, alpha=No
         None : Use same colorscheme as for c
         [0,0,0] : If the input is a single color, all fonts will get this color.
     norm : Bool, optional
-        Normalize datapoints. The default is True.
+        Normalize datapoints. The default is False.
     cmap : String, optional
         'Set1'       (default)
         'Set2'
@@ -80,34 +94,42 @@ def scatterd(x, y, z=None, s=50, c=[0, 0, 0], labels=None, marker=None, alpha=No
     --------
     >>> # Import library
     >>> from scatterd import scatterd, import_example
+    >>>
     >>> # Import example
     >>> df = import_example()
-    >>> # plain scatter plot
-    >>> ax = scatterd(df['tsneX'], df['tsneY'])
-    >>> # plain scatter plot
-    >>> ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'])
-    >>> # Gradient
-    >>> ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], gradient='#FFFFFF')
+    >>>
+    >>> # Simple scatter
+    >>> fig, ax = scatterd(df['tsneX'], df['tsneY'])
+    >>>
+    >>> # Scatter with labels
+    >>> fig, ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'])
+    >>>
+    >>> # Scatter with gradient
+    >>> fig, ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], gradient='#FFFFFF')
+    >>>
     >>> # Change cmap
-    >>> ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], gradient='#FFFFFF', cmap='Set2')
-    >>> # Density
-    >>> ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], density=True)
-    >>> # Density with gradient
-    >>> ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], density=True, gradient='#FFFFFF')
+    >>> fig, ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], gradient='#FFFFFF', cmap='Set2')
+    >>>
+    >>> # Scatter with density
+    >>> fig, ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], density=True)
+    >>>
+    >>> # Scatter with density and gradient
+    >>> fig, ax = scatterd(df['tsneX'], df['tsneY'], labels=df['labx'], density=True, gradient='#FFFFFF')
     >>>
 
     References
     -------
-    Colormap: https://matplotlib.org/examples/color/colormaps_reference.html
+    * github: https://github.com/erdogant/scatterd
+    * Documentation: https://erdogant.github.io/scatterd/
+    * Colormap: https://matplotlib.org/examples/color/colormaps_reference.html
 
     """
     fig = None
-    if len(x)!=len(y): raise Exception('[scatterd] >Error: X should have same length as Y.')
-    if s is None: raise Exception('[scatterd] >Error: input parameter s(ize) should be not None.')
+    if len(x)!=len(y): raise Exception('[scatterd] >Error: input parameter x should be the same size of y.')
+    if s is None: raise Exception('[scatterd] >Error: input parameter s(ize) should have value >0.')
     if c is None: raise Exception('[scatterd] >Error: input parameter c(olors) should be not None.')
     if isinstance(c, str): raise Exception('[scatterd] >Error: input parameter c(olors) should be RGB of type tuple [0,0,0] .')
     if not isinstance(s, int) and len(s)!=len(x): raise Exception('[scatterd] >Error: input parameter s(ize) should be of same size of X.')
-    if len(x)!=len(y): raise Exception('[scatterd] >Error: input parameter x should be the same size of y.')
     if (z is not None) and len(x)!=len(z): raise Exception('[scatterd] >Error: input parameter z should be the same size of x and y.')
 
     # Defaults
@@ -193,7 +215,7 @@ def _set_figure_properties(X, labels, fontcolor, fontsize, xlabel, ylabel, title
 
 # %% Setup colors
 def set_colors(X, labels, fontcolor, c, cmap, gradient=None):
-
+    """Set colors."""
     # Create unqiue colors for labels
     if len(np.unique(labels))>1:
         c_rgb, _ = colourmap.fromlist(labels, cmap=cmap, method='matplotlib', gradient=gradient)
@@ -215,6 +237,7 @@ def set_colors(X, labels, fontcolor, c, cmap, gradient=None):
 
 # %% Create gradient based on density.
 def gradient_on_density_color(X, c_rgb, labels):
+    """Set gradient on density color."""
     from scipy.stats import gaussian_kde
     uilabels = np.unique(labels)
     density_colors= np.repeat([1., 1., 1.], len(labels), axis=0).reshape(-1, 3)
@@ -227,13 +250,14 @@ def gradient_on_density_color(X, c_rgb, labels):
             else:
                 xy = np.vstack([X[idx, 0], X[idx, 1], X[idx, 2]])
 
-            if len(idx)>1:
+            try:
                 # Compute density
                 z = gaussian_kde(xy)(xy)
                 # Sort on density
                 didx = idx[np.argsort(z)[::-1]]
-            else:
+            except:
                 didx=idx
+
             # order colors correctly based Density
             density_colors[didx] = c_rgb[idx, :]
             # plt.figure()
